@@ -45,14 +45,14 @@
 #include "clock.h"
 #include "clock-utils.h"
 #include "clock-typebuiltins.h"
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 #include "calendar-client.h"
 #endif
 
 #define CALENDAR_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CALENDAR_TYPE_WINDOW, CalendarWindowPrivate))
 
 #define KEY_LOCATIONS_EXPANDED      "expand-locations"
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 #  define KEY_APPOINTMENTS_EXPANDED "expand-appointments"
 #  define KEY_BIRTHDAYS_EXPANDED    "expand-birthdays"
 #  define KEY_TASKS_EXPANDED        "expand-tasks"
@@ -81,7 +81,7 @@ struct _CalendarWindowPrivate {
 
 	GtkWidget *locations_list;
 
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	GDesktopClockFormat time_format;
 
         CalendarClient *client;
@@ -100,7 +100,7 @@ struct _CalendarWindowPrivate {
         GtkTreeModelFilter *birthdays_filter;
         GtkTreeModelFilter *tasks_filter;
         GtkTreeModelFilter *weather_filter;
-#endif /* HAVE_LIBECAL */
+#endif /* HAVE_EDS */
 };
 
 G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW)
@@ -126,91 +126,51 @@ static GtkWidget * create_hig_frame 		  (CalendarWindow *calwin,
 						   GCallback   callback,
 						   gboolean    bind_to_locked_down);
 
-#ifdef HAVE_LIBECAL
-
-/*
- * Set the DISPLAY variable, to be use by g_spawn_async.
- */
-static void
-set_environment (gpointer display)
-{
-	g_setenv ("DISPLAY", display, TRUE);
-}
+#ifdef HAVE_EDS
 
 static void
 clock_launch_calendar_tasks_app (CalendarWindow *calwin,
-				 const char     *schema_program,
-				 const char     *argument)
+                                 const gchar    *schema_program,
+                                 const gchar    *argument)
 {
-	GSettings  *settings;
-	char      **argv;
-	int         argc;
-	char       *program;
-	gboolean    terminal;
-	char       *command_line;
-	GdkScreen  *screen;
-	GError     *error;
-	gboolean    result;
-	char       *display;
+	GSettings *settings;
+	gchar *program;
+	gchar *command_line;
+	GAppInfo *app_info;
+	GError *error;
 
 	settings = g_settings_new (schema_program);
 	program = g_settings_get_string (settings, "exec");
-	terminal = g_settings_get_boolean (settings, "needs-term");
 	g_object_unref (settings);
 
 	if (program == NULL) {
-		g_printerr ("Cannot launch calendar/tasks application: key not set\n");
+		g_warning ("Cannot launch calendar/tasks application: key not set");
 		return;
 	}
 
-	/* FIXME: reintroduce terminal support if a proper GAppInfo port of gnome-panel is ever done */
-	if (terminal) {
-		g_printerr ("Terminal-based calendar/tasks applications are no longer supported, sorry. "
-		            "Please configure a different application.\n");
-		return;
-	}
+	if (argument)
+		command_line = g_strdup_printf ("%s %s", program, argument);
+	else
+		command_line = g_strdup (program);
+	g_free (program);
 
-	command_line = g_find_program_in_path (program);
-	if (command_line == NULL) {
-		g_printerr ("Cannot launch calendar/tasks application: %s in path\n", program);
-		g_free (program);
-		return;
-	}
+	error = NULL;
+	app_info = g_app_info_create_from_commandline (command_line,
+	                                               NULL,
+	                                               G_APP_INFO_CREATE_NONE,
+	                                               &error);
 	g_free (command_line);
 
-	if (argument) {
-		argc = 2;
-		argv = g_new0 (char *, 3);
-		argv[1] = g_strdup (argument);
-	} else {
-		argc = 1;
-		argv = g_new0 (char *, 2);
+	if (error) {
+		g_warning ("Cannot launch calendar/tasks application: %s", error->message);
+		g_error_free (error);
+		return;
 	}
-	argv[0] = program; /* no strdup, and it will get freed for free */
 
-	screen = gtk_widget_get_screen (calwin->priv->calendar);
-	error = NULL;
-
-	display = gdk_screen_make_display_name (screen);
-
-	result = g_spawn_async (NULL, /* working directory */
-			        argv,
-				NULL, /* envp */
-				G_SPAWN_SEARCH_PATH,
-				set_environment, /* child setup func */
-				&display, /* user data for child setup */
-				NULL,     /* child pid */
-				&error);
-
-	g_free (display);
-
-	if (!result) {
-		g_printerr ("Cannot launch calendar/tasks application: %s\n",
-			    error->message);
+	if (!g_app_info_launch (app_info, NULL, NULL, &error)) {
+		g_warning ("Cannot launch calendar/tasks application: %s", error->message);
 		g_error_free (error);
 	}
-
-	g_strfreev (argv);
 }
 
 static void
@@ -254,7 +214,7 @@ enum {
         APPOINTMENT_COLUMN_START_TEXT,
         APPOINTMENT_COLUMN_END_TIME,
         APPOINTMENT_COLUMN_ALL_DAY,
-        APPOINTMENT_COLUMN_PIXBUF,
+        APPOINTMENT_COLUMN_COLOR,
         N_APPOINTMENT_COLUMNS
 };
 
@@ -573,26 +533,25 @@ set_renderer_pixbuf_color_by_column (GtkCellRenderer *renderer,
                                      GtkTreeIter     *iter,
                                      gint             column_number)
 {
-        char      *color_string;
-        GdkPixbuf *pixbuf = NULL;
-        GdkColor   color;
+        gchar *color_string;
+        GdkRGBA color;
 
         gtk_tree_model_get (model, iter, column_number, &color_string, -1);
 
-        if (color_string && gdk_color_parse (color_string, &color)) {
-                pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 16, 16);
-                /* GdkColor has 16 bits per color, gdk_pixbuf only uses 8 bits
-                 * per color. So just drop the least significant parts */
-                gdk_pixbuf_fill (pixbuf,
-				 (color.red   & 0xff00) << 16 |
-				 (color.green & 0xff00) << 8  | 
-				 (color.blue  & 0xff00));
+        if (color_string && gdk_rgba_parse (&color, color_string)) {
+                cairo_surface_t *surface;
+                cairo_t *cr;
 
-                g_object_set (renderer, "visible", pixbuf != NULL, "pixbuf", pixbuf, NULL);
+                surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24, 16, 16);
+                cr = cairo_create (surface);
 
-                if (pixbuf)
-                        g_object_unref (pixbuf);
+                gdk_cairo_set_source_rgba (cr, &color);
+                cairo_paint (cr);
 
+                g_object_set (renderer, "visible", surface != NULL, "surface", surface, NULL);
+
+                cairo_destroy (cr);
+                cairo_surface_destroy (surface);
                 g_free (color_string);
         }
 }
@@ -690,7 +649,7 @@ appointment_pixbuf_cell_data_func (GtkTreeViewColumn *column,
         set_renderer_pixbuf_color_by_column (renderer,
                                              model,
                                              iter,
-                                             APPOINTMENT_COLUMN_PIXBUF);
+                                             APPOINTMENT_COLUMN_COLOR);
 }
 static void
 birthday_pixbuf_cell_data_func (GtkTreeViewColumn   *column,
@@ -973,7 +932,7 @@ handle_appointments_changed (CalendarWindow *calwin)
                                     APPOINTMENT_COLUMN_START_TEXT,  start_text,
                                     APPOINTMENT_COLUMN_END_TIME,    (gint64)appointment->end_time,
                                     APPOINTMENT_COLUMN_ALL_DAY,     appointment->is_all_day,
-                                    APPOINTMENT_COLUMN_PIXBUF,      appointment->color_string,
+                                    APPOINTMENT_COLUMN_COLOR,       appointment->color_string,
                                     -1);
 
                 g_free (start_text);
@@ -1269,43 +1228,70 @@ calendar_month_selected (GtkCalendar    *calendar,
         handle_tasks_changed (calwin);
 }
 
-static void
-setup_list_size_constraint (GtkWidget *widget,
-                            GtkWidget *calendar,
-                            GtkWidget *tree)
+typedef struct
 {
-	GtkRequisition   req;
+        GtkWidget *calendar;
+        GtkWidget *tree;
+} ConstraintData;
+
+static void
+constrain_list_size (GtkWidget      *widget,
+                     GtkAllocation  *allocation,
+                     ConstraintData *constraint)
+{
+        GtkRequisition   req;
 	GtkStyleContext *context;
 	GtkStateFlags    state;
 	GtkBorder        padding;
-	int              screen_h;
-	int              max_height;
-	int              req_height;
+        int              screen_h;
+        int              width;
+        int              height;
+        int              max_height;
 
-	/* constrain width to the calendar width */
-	gtk_widget_get_preferred_size (calendar, &req, NULL);
+        /* constrain width to the calendar width */
+        gtk_widget_get_preferred_size (constraint->calendar, &req, NULL);
+        width = MIN (allocation->width, req.width);
 
 	screen_h = gdk_screen_get_height (gtk_widget_get_screen (widget));
         /* constrain height to be the tree height up to a max */
-	max_height = (screen_h - req.height) / 3;
-	gtk_widget_get_preferred_size (tree, &req, NULL);
+        max_height = (screen_h - req.height) / 3;
+        gtk_widget_get_preferred_size (constraint->tree, &req, NULL);
 
 	state = gtk_widget_get_state_flags (widget);
 	context = gtk_widget_get_style_context (widget);
 	gtk_style_context_get_padding (context, state, &padding);
 
-	req_height = MIN (req.height, max_height);
-	req_height += padding.top + padding.bottom;
-	gtk_widget_set_size_request (widget, req.width, req_height);
+        height = MIN (req.height, max_height);
+        height += padding.top + padding.bottom;
+        /* top & bottom border */
+        height += 2;
+
+        gtk_widget_set_size_request (widget, width, height);
 }
 
-#endif /* HAVE_LIBECAL */
+static void
+setup_list_size_constraint (GtkWidget *widget,
+                            GtkWidget *calendar,
+                            GtkWidget *tree)
+{
+        ConstraintData *constraint;
+
+        constraint           = g_new0 (ConstraintData, 1);
+        constraint->calendar = calendar;
+        constraint->tree     = tree;
+
+        g_signal_connect_data (widget, "size-allocate",
+                               G_CALLBACK (constrain_list_size), constraint,
+                               (GClosureNotify) g_free, 0);
+}
+
+#endif /* HAVE_EDS */
 
 static void
 calendar_window_pack_pim (CalendarWindow *calwin,
 			  GtkWidget      *vbox)
 {
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	GtkWidget *list;
         GtkWidget *tree_view;
         GtkWidget *scrolled_window;
@@ -1404,7 +1390,7 @@ calendar_window_pack_pim (CalendarWindow *calwin,
 			  "month-changed",
 			  G_CALLBACK (calendar_month_selected),
 			  calwin);
-#endif /* HAVE_LIBECAL */
+#endif /* HAVE_EDS */
 }
 
 static GtkWidget *
@@ -1476,12 +1462,9 @@ create_hig_frame (CalendarWindow *calwin,
 		  gboolean    bind_to_locked_down)
 {
         GtkWidget *vbox;
-        GtkWidget *alignment;
         GtkWidget *label;
         GtkWidget *hbox;
-        GtkWidget *button;
         char      *bold_title;
-	char      *text;
         GtkWidget *expander;
 
         vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -1508,29 +1491,44 @@ create_hig_frame (CalendarWindow *calwin,
 	g_signal_connect (hbox, "add", G_CALLBACK (add_child), expander);
 
         if (button_label) {
+                GtkWidget *button_box;
+                GtkWidget *button;
+                gchar *text;
+
+                button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+                gtk_widget_show (button_box);
+
                 button = gtk_button_new ();
+                gtk_container_add (GTK_CONTAINER (button_box), button);
+
                 text = g_markup_printf_escaped ("<small>%s</small>", button_label);
                 label = gtk_label_new (text);
                 g_free (text);
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
                 gtk_container_add (GTK_CONTAINER (button), label);
 
-		alignment = gtk_alignment_new (1, 0, 0, 0);
-                gtk_container_add (GTK_CONTAINER (alignment), button);
-        	gtk_widget_show_all (alignment);
+                gtk_widget_show_all (button);
 
-                gtk_box_pack_end (GTK_BOX (hbox), alignment, TRUE, TRUE, 0);
+                gtk_box_pack_end (GTK_BOX (hbox), button_box, FALSE, FALSE, 0);
 
                 g_signal_connect_swapped (button, "clicked", callback, calwin);
 
-		if (bind_to_locked_down)
-			g_object_bind_property (calwin, "locked-down",
-						button, "visible",
-						G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
+                g_object_bind_property (expander, "expanded",
+                                        button_box, "visible",
+                                        G_BINDING_DEFAULT|G_BINDING_SYNC_CREATE);
+
+                if (bind_to_locked_down) {
+                        g_object_bind_property (calwin, "locked-down",
+                                                button, "visible",
+                                                G_BINDING_DEFAULT |
+                                                G_BINDING_INVERT_BOOLEAN |
+                                                G_BINDING_SYNC_CREATE);
+                }
         }
 
-	g_settings_bind (calwin->priv->settings, key, expander, "expanded",
-			 G_SETTINGS_BIND_DEFAULT);
+        g_settings_bind (calwin->priv->settings, key,
+                         expander, "expanded",
+                         G_SETTINGS_BIND_DEFAULT);
 
         return vbox;
 }
@@ -1691,7 +1689,7 @@ calendar_window_set_property (GObject       *object,
 static void
 calendar_window_dispose (GObject *object)
 {
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	CalendarWindow *calwin;
 
 	calwin = CALENDAR_WINDOW (object);
@@ -1725,7 +1723,7 @@ calendar_window_dispose (GObject *object)
         calwin->priv->weather_filter = NULL;
 
 	g_clear_object (&calwin->priv->settings);
-#endif /* HAVE_LIBECAL */
+#endif /* HAVE_EDS */
 
 	G_OBJECT_CLASS (calendar_window_parent_class)->dispose (object);
 }
@@ -1803,7 +1801,7 @@ calendar_window_init (CalendarWindow *calwin)
 	gtk_window_set_title (window, _("Calendar"));
 	gtk_window_set_icon_name (window, CLOCK_ICON);
 
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	calwin->priv->previous_selection = NULL;
 #endif
 }
@@ -1828,7 +1826,7 @@ calendar_window_refresh (CalendarWindow *calwin)
 {
 	g_return_if_fail (CALENDAR_IS_WINDOW (calwin));
 
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	if (calwin->priv->appointments_filter && calwin->priv->appointment_list)
 		gtk_tree_model_filter_refilter (calwin->priv->appointments_filter);
 	if (calwin->priv->birthdays_filter && calwin->priv->birthday_list)
@@ -1905,7 +1903,7 @@ calendar_window_get_time_format (CalendarWindow *calwin)
 	g_return_val_if_fail (CALENDAR_IS_WINDOW (calwin),
 			      G_DESKTOP_CLOCK_FORMAT_24H);
 
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	return calwin->priv->time_format;
 #else
 	return G_DESKTOP_CLOCK_FORMAT_24H;
@@ -1918,7 +1916,7 @@ calendar_window_set_time_format (CalendarWindow      *calwin,
 {
 	g_return_if_fail (CALENDAR_IS_WINDOW (calwin));
 
-#ifdef HAVE_LIBECAL
+#ifdef HAVE_EDS
 	if (time_format != G_DESKTOP_CLOCK_FORMAT_12H &&
 	    time_format != G_DESKTOP_CLOCK_FORMAT_24H)
 		time_format = clock_locale_format ();
