@@ -41,8 +41,6 @@
 #define FISH_APPLET(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), \
 			fish_applet_get_type(),          \
 			FishApplet))
-#define FISH_IS_APPLET(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
-			   FISH_TYPE_APPLET))
 
 #define FISH_ICON "gnome-panel-fish"
 #define FISH_RESOURCE_PATH "/org/gnome/panel/applet/fish/"
@@ -104,7 +102,6 @@ typedef struct {
 	PanelAppletClass klass;
 } FishAppletClass;
 
-
 static gboolean load_fish_image          (FishApplet *fish);
 static void     update_surface           (FishApplet *fish);
 static void     something_fishy_going_on (FishApplet *fish,
@@ -114,7 +111,7 @@ static void     set_tooltip              (FishApplet *fish);
 
 static GType fish_applet_get_type (void);
 
-static GObjectClass *parent_class;
+G_DEFINE_TYPE (FishApplet, fish_applet, PANEL_TYPE_APPLET)
 
 static int fools_day        = 0;
 static int fools_month      = 0;
@@ -258,14 +255,27 @@ handle_response (GtkWidget  *widget,
 	gtk_widget_hide (fish->preferences_dialog);
 }
 
-static void 
-display_preferences_dialog (GtkAction  *action,
-			    FishApplet *fish)
+static void
+fill_combo_box_text (GtkComboBoxText *combo)
 {
+	gtk_combo_box_text_append (combo, "wanda.fish", "Wanda");
+	gtk_combo_box_text_append (combo, "monkey.fish", "Monkey");
+	gtk_combo_box_text_append (combo, "oldwanda.fish", "Old Wanda");
+	gtk_combo_box_text_append (combo, "fishanim.fish", "Fish Anim");
+	gtk_combo_box_text_append (combo, "footguy.fish", "Foot Guy");
+}
+
+static void 
+display_preferences_dialog (GSimpleAction *action,
+                            GVariant      *parameter,
+                            gpointer       user_data)
+{
+	FishApplet *fish = FISH_APPLET (user_data);
 	GtkBuilder *builder;
 	GtkWidget  *box;
 	GtkWidget  *name_entry;
 	GtkWidget  *command_entry;
+	GtkWidget  *image;
 	GtkWidget  *speed_spin;
 	GtkWidget  *rotate_toggle;
 	GtkWidget  *button;
@@ -317,6 +327,12 @@ display_preferences_dialog (GtkAction  *action,
 			 box, "visible",
 			 G_SETTINGS_BIND_DEFAULT|G_SETTINGS_BIND_INVERT_BOOLEAN);
 
+	image = GTK_WIDGET (gtk_builder_get_object (builder, "image_comboboxtext"));
+	fill_combo_box_text (GTK_COMBO_BOX_TEXT (image));
+	g_settings_bind (fish->settings, FISH_IMAGE_KEY,
+	                 GTK_COMBO_BOX (image), "active-id",
+	                 G_SETTINGS_BIND_DEFAULT);
+
 	speed_spin = GTK_WIDGET (gtk_builder_get_object (builder, "speed_spin"));
 	box = GTK_WIDGET (gtk_builder_get_object (builder, "speed_box"));
 	g_settings_bind (fish->settings, FISH_SPEED_KEY,
@@ -621,7 +637,7 @@ display_fortune_dialog (FishApplet *fish)
 			gtk_dialog_new_with_buttons (
 				"", NULL, 0,
 				_("_Speak again"), FISH_RESPONSE_SPEAK,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+				_("_Close"), GTK_RESPONSE_CLOSE,
 				NULL);
 
 		gtk_window_set_icon_name (GTK_WINDOW (fish->fortune_dialog),
@@ -671,8 +687,7 @@ display_fortune_dialog (FishApplet *fish)
 		gtk_label_set_ellipsize (GTK_LABEL (fish->fortune_label),
 					 PANGO_ELLIPSIZE_MIDDLE);
 		fish->fortune_cmd_label = gtk_label_new ("");
-		gtk_misc_set_alignment (GTK_MISC (fish->fortune_cmd_label),
-					0, 0.5);
+		gtk_label_set_xalign (GTK_LABEL (fish->fortune_cmd_label), 0.0);
 
 		vbox = gtk_dialog_get_content_area (GTK_DIALOG (fish->fortune_dialog));
 		gtk_box_pack_start (GTK_BOX (vbox),
@@ -1301,10 +1316,8 @@ setup_fish_widget (FishApplet *fish)
 	gtk_widget_show_all (widget);
 }
 
-static const GtkActionEntry fish_menu_verbs [] = {
-	{ "FishPreferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (display_preferences_dialog) }
+static const GActionEntry fish_menu_actions [] = {
+	{ "preferences", display_preferences_dialog, NULL, NULL, NULL }
 };
 
 static void
@@ -1403,14 +1416,17 @@ fish_applet_settings_changed (GSettings  *settings,
 	if (!key || g_strcmp0 (key, FISH_NAME_KEY) == 0) {
 		value_str = g_settings_get_string (settings, FISH_NAME_KEY);
 		fish_applet_update_name (fish, value_str);
+		g_free (value_str);
 	}
 	if (!key || g_strcmp0 (key, FISH_IMAGE_KEY) == 0) {
 		value_str = g_settings_get_string (settings, FISH_IMAGE_KEY);
 		fish_applet_update_image (fish, value_str);
+		g_free (value_str);
 	}
 	if (!key || g_strcmp0 (key, FISH_COMMAND_KEY) == 0) {
 		value_str = g_settings_get_string (settings, FISH_COMMAND_KEY);
 		fish_applet_update_command (fish, value_str);
+		g_free (value_str);
 	}
 	if (!key || g_strcmp0 (key, FISH_SPEED_KEY) == 0) {
 		value_double = g_settings_get_double (settings, FISH_SPEED_KEY);
@@ -1420,49 +1436,46 @@ fish_applet_settings_changed (GSettings  *settings,
 		value_boolean = g_settings_get_boolean (settings, FISH_ROTATE_KEY);
 		fish_applet_update_rotate (fish, value_boolean);
 	}
-
-	g_free (value_str);
 }
 
 static gboolean
 fish_applet_fill (FishApplet *fish)
 {
-	PanelApplet    *applet = (PanelApplet *) fish;
-	GtkActionGroup *action_group;
-	GtkAction      *action;
+	PanelApplet        *applet = PANEL_APPLET (fish);
+	GSimpleActionGroup *action_group;
+	GAction            *action;
 
 	fish->orientation = panel_applet_get_orient (applet);
 
 	fish->settings = panel_applet_settings_new (applet, FISH_SCHEMA);
 	fish->lockdown_settings = g_settings_new (LOCKDOWN_SCHEMA);
 
-	g_signal_connect (fish->settings, "changed",
-			  G_CALLBACK (fish_applet_settings_changed), fish);
-	/* NULL means we will update for all settings */
-	fish_applet_settings_changed (fish->settings, NULL, fish);
-
-	action_group = gtk_action_group_new ("Fish Applet Actions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (action_group,
-				      fish_menu_verbs,
-				      G_N_ELEMENTS (fish_menu_verbs),
-				      fish);
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 fish_menu_actions,
+	                                 G_N_ELEMENTS (fish_menu_actions),
+	                                 fish);
 	panel_applet_setup_menu_from_resource (applet,
 					       FISH_RESOURCE_PATH "fish-menu.xml",
-					       action_group);
+					       action_group,
+					       GETTEXT_PACKAGE);
 
-	action = gtk_action_group_get_action (action_group, "FishPreferences");
+	gtk_widget_insert_action_group (GTK_WIDGET (applet), "fish",
+	                                G_ACTION_GROUP (action_group));
+
+	action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
 	g_object_bind_property (applet, "locked-down",
-				action, "visible",
+				action, "enabled",
 				G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
 	g_object_unref (action_group);
 
-#ifndef FISH_INPROCESS
-	gtk_window_set_default_icon_name (FISH_ICON);
-#endif
 	setup_fish_widget (fish);
 
+	g_signal_connect (fish->settings, "changed",
+	                  G_CALLBACK (fish_applet_settings_changed), fish);
+	fish_applet_settings_changed (fish->settings, NULL, fish);
+
 	return TRUE;
 }
 
@@ -1530,12 +1543,11 @@ fish_applet_dispose (GObject *object)
 
 	fish_close_channel (fish);
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (fish_applet_parent_class)->dispose (object);
 }
 
 static void
-fish_applet_instance_init (FishApplet      *fish,
-			   FishAppletClass *klass)
+fish_applet_init (FishApplet *fish)
 {
 	fish->settings          = NULL;
 	fish->lockdown_settings = NULL;
@@ -1581,9 +1593,6 @@ fish_applet_instance_init (FishApplet      *fish,
 
 	panel_applet_set_flags (PANEL_APPLET (fish),
 				PANEL_APPLET_EXPAND_MINOR);
-
-	panel_applet_set_background_widget (PANEL_APPLET (fish),
-					    GTK_WIDGET (fish));
 }
 
 static void
@@ -1592,8 +1601,6 @@ fish_applet_class_init (FishAppletClass *klass)
 	PanelAppletClass *applet_class  = (PanelAppletClass *) klass;
 	GObjectClass     *gobject_class = (GObjectClass *) klass;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	applet_class->change_orient = fish_applet_change_orient;
 
 	gobject_class->dispose = fish_applet_dispose;
@@ -1601,39 +1608,7 @@ fish_applet_class_init (FishAppletClass *klass)
 	init_fools_day ();
 }
 
-static GType
-fish_applet_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (PanelAppletClass),
-			NULL, NULL,
-			(GClassInitFunc) fish_applet_class_init,
-			NULL, NULL,
-			sizeof (FishApplet),
-			0,
-			(GInstanceInitFunc) fish_applet_instance_init,
-			NULL
-		};
-
-		type = g_type_register_static (
-				PANEL_TYPE_APPLET, "FishApplet", &info, 0);
-	}
-
-	return type;
-}
-
-#ifdef FISH_INPROCESS
 PANEL_APPLET_IN_PROCESS_FACTORY ("FishAppletFactory",
 				 fish_applet_get_type (),
 				 fishy_factory,
 				 NULL)
-
-#else
-PANEL_APPLET_OUT_PROCESS_FACTORY ("FishAppletFactory",
-				  fish_applet_get_type (),
-				  fishy_factory,
-				  NULL)
-#endif
