@@ -28,6 +28,7 @@
 #include <gio/gio.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-keyfile.h>
 #include <libpanel-util/panel-xdg.h>
 
@@ -45,7 +46,6 @@
 
 typedef struct {
 	GtkWidget    *pixmap;
-	const char   *stock_id;
 	GIcon        *gicon;
 	char         *image;
 	char         *fallback_image;
@@ -55,7 +55,6 @@ typedef struct {
 
 typedef struct {
 	GtkWidget   *image;
-	const char  *stock_id;
 	GIcon       *gicon;
 	GdkPixbuf   *pixbuf;
 	GtkIconSize  icon_size;
@@ -73,7 +72,6 @@ static GtkWidget *populate_menu_from_directory (GtkWidget          *menu,
 
 static void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 					    GtkIconSize  icon_size,
-					    const char  *stock_id,
 					    GIcon       *gicon,
 					    const char  *image_filename,
 					    const char  *fallback_image_filename);
@@ -268,7 +266,6 @@ icon_to_load_copy (IconToLoad *icon)
 		retval->gicon  = NULL;
 	retval->image          = g_strdup (icon->image);
 	retval->fallback_image = g_strdup (icon->fallback_image);
-	retval->stock_id       = icon->stock_id;
 	retval->icon_size      = icon->icon_size;
 
 	return retval;
@@ -441,15 +438,11 @@ do_icons_to_add (void)
 {
 	while (icons_to_add) {
 		IconToAdd *icon_to_add = icons_to_add->data;
+		int icon_height;
 
 		icons_to_add = g_list_delete_link (icons_to_add, icons_to_add);
 
-		if (icon_to_add->stock_id) {
-			gtk_image_set_from_stock (
-				GTK_IMAGE (icon_to_add->image),
-				icon_to_add->stock_id,
-				icon_to_add->icon_size);
-		} else if (icon_to_add->gicon) {
+		if (icon_to_add->gicon) {
 			gtk_image_set_from_gicon (
 				GTK_IMAGE (icon_to_add->image),
 				icon_to_add->gicon,
@@ -468,6 +461,9 @@ do_icons_to_add (void)
 			g_object_unref (icon_to_add->pixbuf);
 		}
 
+		if (gtk_icon_size_lookup (icon_to_add->icon_size, NULL, &icon_height))
+			gtk_image_set_pixel_size (GTK_IMAGE (icon_to_add->image), icon_height);
+
 		if (icon_to_add->gicon)
 			g_object_unref (icon_to_add->gicon);
 		g_object_unref (icon_to_add->image);
@@ -503,12 +499,11 @@ load_icons_handler_again:
 		goto load_icons_handler_again;
 	}
 
-	if (icon->stock_id || icon->gicon) {
+	if (icon->gicon) {
 		IconToAdd *icon_to_add;
 
 		icon_to_add            = g_new (IconToAdd, 1);
 		icon_to_add->image     = g_object_ref (icon->pixmap);
-		icon_to_add->stock_id  = icon->stock_id;
 		icon_to_add->pixbuf    = NULL;
 		icon_to_add->icon_size = icon->icon_size;
 		if (icon->gicon)
@@ -543,7 +538,6 @@ load_icons_handler_again:
 
 		icon_to_add            = g_new (IconToAdd, 1);
 		icon_to_add->image     = g_object_ref (icon->pixmap);
-		icon_to_add->stock_id  = NULL;
 		icon_to_add->gicon     = NULL;
 		icon_to_add->pixbuf    = pb;
 		icon_to_add->icon_size = icon->icon_size;
@@ -621,8 +615,8 @@ drag_end_menu_cb (GtkWidget *widget, GdkDragContext     *context)
       
       parent = gtk_menu_shell_get_parent_shell (GTK_MENU_SHELL (parent));
     }
-  
-  if (xgrab_shell && !gtk_menu_get_tearoff_state (GTK_MENU(xgrab_shell)))
+
+  if (xgrab_shell)
     {
       gboolean      status;
       GdkDisplay    *display;
@@ -630,7 +624,8 @@ drag_end_menu_cb (GtkWidget *widget, GdkDragContext     *context)
       GdkDevice     *keyboard;
       GdkDeviceManager *device_manager;
       GdkWindow *window = gtk_widget_get_window (xgrab_shell);
-      GdkCursor *cursor = gdk_cursor_new (GDK_ARROW);
+      GdkCursor *cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
+                                                      GDK_ARROW);
 
       display = gdk_window_get_display (window);
       device_manager = gdk_display_get_device_manager (display);
@@ -782,7 +777,7 @@ setup_menuitem (GtkWidget   *menuitem,
 
 	gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (label), menuitem);
 
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0);
 	gtk_widget_show (label);
        
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
@@ -793,8 +788,7 @@ setup_menuitem (GtkWidget   *menuitem,
 					g_object_ref (image),
 					(GDestroyNotify) g_object_unref);
 		gtk_widget_show (image);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
-					       image);
+		panel_image_menu_item_set_image (PANEL_IMAGE_MENU_ITEM (menuitem), image);
 	} else if (icon_size != GTK_ICON_SIZE_INVALID)
                 image_menuitem_set_size_request (menuitem, icon_size);
 
@@ -975,14 +969,13 @@ create_fake_menu (GMenuTreeDirectory *directory)
 }
 
 GtkWidget *
-panel_image_menu_item_new (void)
+panel_image_menu_item_new2 (void)
 {
 	GtkWidget *menuitem;
 	GtkStyleContext *context;
 
-	menuitem = gtk_image_menu_item_new ();
-	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem),
-						   TRUE);
+	menuitem = panel_image_menu_item_new ();
+	panel_image_menu_item_set_always_show_image (PANEL_IMAGE_MENU_ITEM (menuitem), TRUE);
 	context = gtk_widget_get_style_context (menuitem);
 	gtk_style_context_add_class (context, "gnome-panel-menu-item");
 
@@ -1000,13 +993,12 @@ create_submenu_entry (GtkWidget          *menu,
 						   "panel-menu-force-icon-for-categories") != NULL;
 
 	if (force_categories_icon)
-		menuitem = panel_image_menu_item_new ();
+		menuitem = panel_image_menu_item_new2 ();
 	else
-		menuitem = gtk_image_menu_item_new ();
+		menuitem = panel_image_menu_item_new ();
 
 	panel_load_menu_image_deferred (menuitem,
 					panel_menu_icon_get_size (),
-					NULL,
 					gmenu_tree_directory_get_icon (directory),
 					NULL,
 					PANEL_ICON_FOLDER);
@@ -1071,19 +1063,18 @@ create_menuitem (GtkWidget          *menu,
 {
 	GtkWidget  *menuitem;
 	
-	menuitem = panel_image_menu_item_new ();
+	menuitem = panel_image_menu_item_new2 ();
 
 	if (alias_directory)
 		panel_load_menu_image_deferred (menuitem,
 						panel_menu_icon_get_size (),
-						NULL,
 						gmenu_tree_directory_get_icon (alias_directory),
 						NULL,
 						NULL);
 	else
 		panel_load_menu_image_deferred (menuitem,
 						panel_menu_icon_get_size (),
-						NULL, g_app_info_get_icon (G_APP_INFO (gmenu_tree_entry_get_app_info (entry))),
+						g_app_info_get_icon (G_APP_INFO (gmenu_tree_entry_get_app_info (entry))),
 						NULL, NULL);
 
 	setup_menuitem (menuitem,
@@ -1346,14 +1337,12 @@ void
 setup_menu_item_with_icon (GtkWidget   *item,
 			   GtkIconSize  icon_size,
 			   const char  *icon_name,
-			   const char  *stock_id,
 			   GIcon       *gicon,
 			   const char  *title)
 {
-	if (icon_name || gicon || stock_id)
+	if (icon_name || gicon)
 		panel_load_menu_image_deferred (item, icon_size,
-						stock_id, gicon,
-						icon_name, NULL);
+						gicon, icon_name, NULL);
 
 	setup_menuitem (item, icon_size, NULL, title);
 }
@@ -1398,8 +1387,11 @@ GtkWidget *
 create_main_menu (PanelWidget *panel)
 {
 	GtkWidget *main_menu;
+	gchar *applications_menu;
 
-	main_menu = create_applications_menu ("gnome-applications.menu", NULL, TRUE);
+	applications_menu = get_applications_menu ();
+	main_menu = create_applications_menu (applications_menu, NULL, TRUE);
+	g_free (applications_menu);
 
 	g_object_set_data (G_OBJECT (main_menu), "menu_panel", panel);
 	/* FIXME need to update the panel on parent_set */
@@ -1456,7 +1448,6 @@ image_menu_destroy (GtkWidget *image, gpointer data)
 static void
 panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 				GtkIconSize  icon_size,
-				const char  *stock_id,
 				GIcon       *gicon,
 				const char  *image_filename,
 				const char  *fallback_image_filename)
@@ -1475,7 +1466,6 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 	/* this takes over the floating ref */
 	icon->pixmap = g_object_ref_sink (G_OBJECT (image));
 
-	icon->stock_id       = stock_id;
 	if (gicon)
 		icon->gicon  = g_object_ref (gicon);
 	else
@@ -1491,8 +1481,7 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 				g_object_ref (image),
 				(GDestroyNotify) g_object_unref);
 
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (image_menu_item),
-				       image);
+	panel_image_menu_item_set_image (PANEL_IMAGE_MENU_ITEM (image_menu_item), image);
 
 	g_signal_connect_data (image, "map",
 			       G_CALLBACK (image_menu_shown), icon,
@@ -1503,3 +1492,11 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 
 	image_menu_items = g_slist_prepend (image_menu_items, image);
 }
+
+gchar *
+get_applications_menu (void)
+{
+	const gchar *xdg_menu_prefx = g_getenv ("XDG_MENU_PREFIX");
+	return g_strdup_printf ("%sapplications.menu",
+	                        !PANEL_GLIB_STR_EMPTY (xdg_menu_prefx) ? xdg_menu_prefx : "gnome-");
+}
