@@ -46,6 +46,7 @@
 #include <libpanel-util/panel-end-session-dialog.h>
 #include <libpanel-util/panel-session-manager.h>
 #include <libpanel-util/panel-show.h>
+#include <gdm/gdm-user-switching.h>
 
 #include "menu.h"
 #include "panel-action-button.h"
@@ -342,20 +343,20 @@ panel_menu_items_create_action_item (PanelActionButtonType action_type)
 							 NULL, NULL, FALSE);
 }
 
-#define GDM_FLEXISERVER_COMMAND "gdmflexiserver"
-#define GDM_FLEXISERVER_ARGS    "--startnew"
-
 static void
 panel_menu_item_activate_switch_user (GtkWidget *menuitem,
 				      gpointer   user_data)
 {
+	GError *error;
+
 	if (panel_lockdown_get_disable_switch_user_s ())
 		return;
 
+	error = NULL;
+
 	/* If running under LightDM switch to the greeter using dbus */
 	if (g_getenv("XDG_SEAT_PATH")) {
 		GDBusConnection *bus;
-		GError  *error = NULL;
 		GVariant *result = NULL;
 
 		bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
@@ -382,29 +383,13 @@ panel_menu_item_activate_switch_user (GtkWidget *menuitem,
                 if (result)
                         g_variant_unref (result);
         } else {
-		GdkScreen *screen;
-		GAppInfo  *app_info;
+		gboolean ret;
 
-		screen = gtk_widget_get_screen (GTK_WIDGET (menuitem));
-		app_info = g_app_info_create_from_commandline (GDM_FLEXISERVER_COMMAND " " GDM_FLEXISERVER_ARGS,
-							       GDM_FLEXISERVER_COMMAND,
-							       G_APP_INFO_CREATE_NONE,
-							       NULL);
+		ret = gdm_goto_login_session_sync (NULL, &error);
 
-		if (app_info) {
-			GdkAppLaunchContext *launch_context;
-			GdkDisplay          *display;
-
-			display = gdk_screen_get_display (screen);
-			launch_context = gdk_display_get_app_launch_context (display);
-			gdk_app_launch_context_set_screen (launch_context, screen);
-
-			g_app_info_launch (app_info, NULL,
-					   G_APP_LAUNCH_CONTEXT (launch_context),
-					   NULL);
-
-			g_object_unref (launch_context);
-			g_object_unref (app_info);
+		if (!ret) {
+			g_warning ("Failed to switch to greeter: %s", error->message);
+			g_error_free (error);
 		}
 	}
 }
