@@ -31,18 +31,6 @@ G_BEGIN_DECLS
 /* themeable size - "panel-menu" -- This is used for the icons in the menus */
 #define PANEL_DEFAULT_MENU_ICON_SIZE 		24
 
-/* stock icons */
-#define PANEL_STOCK_FORCE_QUIT          "gnome-panel-force-quit"
-
-/* stock items  - no point in theme the icons one these,
- * they use stock gtk icons and just modify the text
- * for the stock item.
- */
-#define PANEL_STOCK_EXECUTE             "panel-execute"
-#define PANEL_STOCK_CLEAR               "panel-clear"
-#define PANEL_STOCK_DONT_DELETE         "panel-dont-delete"
-
-void        panel_init_stock_icons_and_items (void);
 GtkIconSize panel_menu_icon_get_size         (void);
 
 G_END_DECLS
