@@ -10,7 +10,6 @@
 #ifndef PANEL_WIDGET_H
 #define PANEL_WIDGET_H
 
-
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "button-widget.h"
@@ -25,8 +24,6 @@ G_BEGIN_DECLS
 #define PANEL_WIDGET_CLASS(klass)  	(G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_WIDGET, PanelWidgetClass))
 #define PANEL_IS_WIDGET(object)       	(G_TYPE_CHECK_INSTANCE_TYPE ((object), PANEL_TYPE_WIDGET)) 
 
-#define PANEL_MINIMUM_WIDTH 12
-
 #define PANEL_APPLET_DATA "panel_applet_data"
 
 #ifndef TYPEDEF_PANEL_WIDGET
@@ -90,8 +87,6 @@ struct _PanelWidget
 	AppletData     *currently_dragged_applet;
 	guint           dragged_state;
 
-	int             thick;
-
 	PanelBackground background;
 
 	GtkWidget      *drop_widget;     /* widget that the panel checks for
@@ -116,7 +111,6 @@ struct _PanelWidgetClass
 {
 	GtkFixedClass parent_class;
 
-	void (* size_change) (PanelWidget *panel);
 	void (* back_change) (PanelWidget *panel);
 	void (* applet_move) (PanelWidget *panel,
 			      GtkWidget *applet);
