@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *	Mark McLoughlin <mark@skynet.ie>
@@ -27,22 +25,11 @@
 
 #include <glib.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-
-#include <X11/Xlib.h>
 
 #include "panel-enums.h"
 
 G_BEGIN_DECLS
 
-typedef enum {
-	PANEL_XUTILS_TYPE_NORMAL,
-	PANEL_XUTILS_TYPE_DOCK
-} PanelXUtilsWindowType;
-
-void panel_xutils_set_window_type (GdkWindow             *gdk_window,
-				   PanelXUtilsWindowType  type);
-
 void panel_xutils_set_strut       (GdkWindow             *gdk_window,
 				   PanelOrientation       orientation,
 				   guint32                strut,
