@@ -25,13 +25,9 @@
 
 #include <glib.h>
 #include <gdk/gdk.h>
-#include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
 
-void  panel_applet_bindings_init  (GConfClient *client);
-void  panel_applet_bindings_clean (GConfClient *client);
-
 guint panel_applet_bindings_get_mouse_button_modifier_keymask (void);
 
 void panel_applet_bindings_key_event_is_popup (GdkEventKey *event,
