@@ -50,7 +50,18 @@ typedef enum {
 	PANEL_APPLET_ORIENT_RIGHT
 } PanelAppletOrient;
 
+/**
+ * PANEL_APPLET_ORIENT_FIRST:
+ *
+ * This macro is an alias for #PANEL_APPLET_ORIENT_UP
+ **/
 #define PANEL_APPLET_ORIENT_FIRST PANEL_APPLET_ORIENT_UP
+
+/**
+ * PANEL_APPLET_ORIENT_LAST:
+ *
+ * This macro is an alias for #PANEL_APPLET_ORIENT_RIGHT
+ **/
 #define PANEL_APPLET_ORIENT_LAST  PANEL_APPLET_ORIENT_RIGHT
 
 #define PANEL_TYPE_APPLET         (panel_applet_get_type ())
@@ -84,7 +95,15 @@ typedef enum {
 	PANEL_APPLET_HAS_HANDLE   = 1 << 2
 } PanelAppletFlags;
 
-#define PANEL_APPLET_FLAGS_ALL (PANEL_APPLET_EXPAND_MAJOR|PANEL_APPLET_EXPAND_MINOR|PANEL_APPLET_HAS_HANDLE)
+/**
+ * PANEL_APPLET_FLAGS_ALL:
+ *
+ * A convenience macro that combines #PANEL_APPLET_EXPAND_MAJOR, #PANEL_APPLET_EXPAND_MINOR and
+ *     #PANEL_APPLET_HAS_HANDLE from #PanelAppletFlags
+ **/
+#define PANEL_APPLET_FLAGS_ALL (PANEL_APPLET_EXPAND_MAJOR | \
+                                PANEL_APPLET_EXPAND_MINOR | \
+                                PANEL_APPLET_HAS_HANDLE)
 
 typedef struct _PanelApplet        PanelApplet;
 typedef struct _PanelAppletClass   PanelAppletClass;
@@ -108,6 +127,12 @@ typedef gboolean (*PanelAppletFactoryCallback) (PanelApplet *applet,
 						const gchar *iid,
 						gpointer     user_data);
 
+/**
+ * PanelApplet:
+ *
+ * #PanelApplet is an opaque data structure and can only be accessed using
+ * the following functions.
+ */
 struct _PanelApplet {
 	GtkEventBox          event_box;
 
@@ -115,15 +140,23 @@ struct _PanelApplet {
 	PanelAppletPrivate  *priv;
 };
 
+/**
+ * PanelAppletClass:
+ * @event_box_class: The parent class.
+ * @change_orient: Signal is emitted when the orientation of applet
+ *    has changed.
+ * @change_background: Signal is emmited when the background af applet
+ *    has changed.
+ * @move_focus_out_of_applet: Signal is emmited when the focus is moved
+ *    out of applet. This is an implementation detail.
+ *
+ * The class structure for the #PanelApplet class.
+ */
 struct _PanelAppletClass {
 	GtkEventBoxClass     event_box_class;
 
 	void (*change_orient) (PanelApplet       *applet,
 			       PanelAppletOrient  orient);
-
-	void (*change_size)   (PanelApplet       *applet,
-			       guint              size);
-
 	void (*change_background) (PanelApplet     *applet,
 				   cairo_pattern_t *pattern);
 	void (*move_focus_out_of_applet) (PanelApplet        *frame,
@@ -133,7 +166,7 @@ struct _PanelAppletClass {
 GType              panel_applet_get_type             (void) G_GNUC_CONST;
  
 PanelAppletOrient  panel_applet_get_orient           (PanelApplet *applet);
-guint              panel_applet_get_size             (PanelApplet *applet);
+GtkOrientation     panel_applet_get_gtk_orientation  (PanelApplet *applet);
 cairo_pattern_t   *panel_applet_get_background       (PanelApplet *applet);
 
 void               panel_applet_set_background_widget (PanelApplet *applet,
@@ -142,12 +175,6 @@ void               panel_applet_set_background_widget (PanelApplet *applet,
 GSettings         *panel_applet_settings_new         (PanelApplet *applet,
 						      const char  *schema);
 
-gchar             *panel_applet_get_preferences_key  (PanelApplet *applet);
-
-void               panel_applet_add_preferences      (PanelApplet  *applet,
-						      const gchar  *schema_dir,
-						      GError      **error);
-
 PanelAppletFlags   panel_applet_get_flags            (PanelApplet      *applet);
 void      	   panel_applet_set_flags            (PanelApplet      *applet,
 						      PanelAppletFlags  flags);
@@ -164,13 +191,16 @@ void               panel_applet_request_focus        (PanelApplet  *applet,
 
 void               panel_applet_setup_menu           (PanelApplet        *applet,
 						      const gchar        *xml,
-						      GtkActionGroup     *action_group);
+						      GSimpleActionGroup *action_group,
+						      const gchar        *translation_domain);
 void               panel_applet_setup_menu_from_file (PanelApplet        *applet,
 						      const gchar        *filename,
-						      GtkActionGroup     *action_group);
+						      GSimpleActionGroup *action_group,
+						      const gchar        *translation_domain);
 void               panel_applet_setup_menu_from_resource (PanelApplet    *applet,
 						          const gchar    *resource_path,
-							  GtkActionGroup *action_group);
+							  GSimpleActionGroup *action_group,
+							  const gchar        *translation_domain);
 
 int                panel_applet_factory_main          (const gchar		  *factory_id,
 						       GType                       applet_type,
@@ -207,9 +237,10 @@ int                panel_applet_factory_setup_in_process (const gchar
 
 /**
  * PANEL_APPLET_OUT_PROCESS_FACTORY:
- * @id: identifier of an applet factory.
+ * @factory_id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
- * @callback: (scope call): callback to be called when a new applet is created.
+ * @callback: (scope call): a %PanelAppletFactoryCallback to be called
+ *     when a new applet is created.
  * @data: (closure): callback data.
  *
  * Convenience macro providing a main() function for an out-of-process applet.
@@ -227,7 +258,7 @@ int                panel_applet_factory_setup_in_process (const gchar
  * It can only be used once, and is incompatible with the use of
  * %PANEL_APPLET_IN_PROCESS_FACTORY and panel_applet_factory_main().
  **/
-#define PANEL_APPLET_OUT_PROCESS_FACTORY(id, type, callback, data)		\
+#define PANEL_APPLET_OUT_PROCESS_FACTORY(factory_id, type, callback, data)      \
 int main (int argc, char *argv [])						\
 {										\
 	GOptionContext *context;						\
@@ -253,7 +284,7 @@ int main (int argc, char *argv [])						\
 										\
 	gtk_init (&argc, &argv);						\
                                                                                 \
-        retval = panel_applet_factory_main (id, type, callback, data);          \
+        retval = panel_applet_factory_main (factory_id, type, callback, data);  \
 	g_option_context_free (context);					\
 										\
 	return retval;								\
@@ -261,9 +292,10 @@ int main (int argc, char *argv [])						\
 
 /**
  * PANEL_APPLET_IN_PROCESS_FACTORY:
- * @id: identifier of an applet factory.
+ * @factory_id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
- * @callback: (scope call): callback to be called when a new applet is created.
+ * @callback: (scope call): a %PanelAppletFactoryCallback to be called
+ *     when a new applet is created.
  * @data: (closure): callback data.
  *
  * Convenience macro providing the symbol needed to automatically register the
@@ -280,13 +312,13 @@ int main (int argc, char *argv [])						\
  * It can only be used once, and is incompatible with the use of
  * %PANEL_APPLET_OUT_PROCESS_FACTORY and panel_applet_factory_main().
  **/
-#define PANEL_APPLET_IN_PROCESS_FACTORY(id, type, callback, data)		\
+#define PANEL_APPLET_IN_PROCESS_FACTORY(factory_id, type, callback, data)       \
 gboolean _panel_applet_shlib_factory (void);					\
 G_MODULE_EXPORT gint                                                            \
 _panel_applet_shlib_factory (void)					        \
 {										\
 	_PANEL_APPLET_SETUP_GETTEXT (FALSE);					\
-        return panel_applet_factory_setup_in_process (id, type,                 \
+        return panel_applet_factory_setup_in_process (factory_id, type,         \
                                                       callback, data);          \
 }
 
